@@ -837,7 +837,7 @@ class Trx(Module):
             contract_address (str): contract address
 
         Returns:
-            SmartContract object.
+            SmartContract object. JSON
 
         """
 
